==> webkitgtk-2.6.5.tar.xz: webkitgtk-2.6.5/Source/WebKit2/WebProcess/WebPage/ViewUpdateDispatcher.h <==
/*
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef ViewUpdateDispatcher_h
#define ViewUpdateDispatcher_h

#include "Connection.h"

#include "VisibleContentRectUpdateInfo.h"
#include <wtf/HashMap.h>
#include <wtf/PassRef.h>
#include <wtf/TCSpinLock.h>

namespace WebKit {

class ViewUpdateDispatcher : public IPC::Connection::WorkQueueMessageReceiver {
public:
    static PassRef<ViewUpdateDispatcher> create();
    ~ViewUpdateDispatcher();

    void initializeConnection(IPC::Connection*);

private:
    ViewUpdateDispatcher();
    // IPC::Connection::WorkQueueMessageReceiver.
    virtual void didReceiveMessage(IPC::Connection*, IPC::MessageDecoder&) override;

    void visibleContentRectUpdate(uint64_t pageID, const VisibleContentRectUpdateInfo&);

    void dispatchVisibleContentRectUpdate();

    struct UpdateData {
        VisibleContentRectUpdateInfo visibleContentRectUpdateInfo;
        double oldestTimestamp;
    };

    RefPtr<WorkQueue> m_queue;
    SpinLock m_dataMutex;
    HashMap<uint64_t, UpdateData> m_latestUpdate;
};

} // namespace WebKit

#endif // ViewportUpdateDispatcher_h

==> webkitgtk-2.8.0.tar.xz: webkitgtk-2.8.0/Source/WebKit2/WebProcess/WebPage/ViewUpdateDispatcher.h <==
/*
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef ViewUpdateDispatcher_h
#define ViewUpdateDispatcher_h

#include "Connection.h"

#include "VisibleContentRectUpdateInfo.h"
#include <wtf/HashMap.h>
#include <wtf/Ref.h>
#include <wtf/TCSpinLock.h>

namespace WebKit {

class ViewUpdateDispatcher : public IPC::Connection::WorkQueueMessageReceiver {
public:
    static Ref<ViewUpdateDispatcher> create();
    ~ViewUpdateDispatcher();

    void initializeConnection(IPC::Connection*);

private:
    ViewUpdateDispatcher();
    // IPC::Connection::WorkQueueMessageReceiver.
    virtual void didReceiveMessage(IPC::Connection&, IPC::MessageDecoder&) override;

    void visibleContentRectUpdate(uint64_t pageID, const VisibleContentRectUpdateInfo&);

    void dispatchVisibleContentRectUpdate();

    struct UpdateData {
        VisibleContentRectUpdateInfo visibleContentRectUpdateInfo;
        double oldestTimestamp;
    };

    Ref<WorkQueue> m_queue;
    SpinLock m_dataMutex;
    HashMap<uint64_t, UpdateData> m_latestUpdate;
};

} // namespace WebKit

#endif // ViewportUpdateDispatcher_h
